#!/bin/sh
CONFIG="debug_conf.json"

RADIO=0
FREQUENCY=868000000
BOARD_RX_FREQ=865000000
BOARD_RX_BW=7000000
BANDWIDTH=125000
SPREADING_FACTOR=7
DEVICE="/dev/slot/1/spidev0"

usage() {
	cat << EOF
usage: ${0##*/} [OPTIONS]

  -d, --dev <device>                             (default ${DEVICE})
  -r, --radio <radio_to_use>                     (0 or 1) (default ${RADIO})
  -f, --radio_frequency <frequency_in_hz>        (default ${FREQUENCY})
  -frx, --board_rx_frequency <frequency_in_hz>   (default ${BOARD_RX_FREQ})
  -frxbw, --board_rx_bw <frequency_in_hz>        (default ${BOARD_RX_BW})
  -b, --bandwidth <bandwidth_in_hz>              (default ${BANDWIDTH})
  -s, --sf <Spreading_factor>                    (default ${SPREADING_FACTOR})
EOF

}

while test $# -gt 0
do
	case $1 in
		-f|--radio_frequency)
			FREQUENCY="${2}"
			shift ;;
		-frx|--board_rx_frequency)
			BOARD_RX_FREQ="${2}"
			shift ;;
		-frxbw|--board_rx_bw)
			BOARD_RX_BW="${2}"
			shift ;;
		-b|--bandwidth)
			BANDWIDTH="${2}"
			shift ;;
		-s|--sf)
			SPREADING_FACTOR="${2}"
			shift ;;
		-r|--radio)
			RADIO="${2}"
			shift ;;
		-d|--dev)
			DEVICE="${2}"
			shift ;;
		*)
			usage && exit 1 ;;
	esac
	shift
done

cat > ${CONFIG} << EOF
{
	"SX1301_array_conf": [
		{
			"board_type": "MASTER",
			"board_rx_freq": ${BOARD_RX_FREQ},
			"board_rx_bw": ${BOARD_RX_BW},
			"full_duplex": false,
			"rf_chain_conf": [
				{
					"rx_enable": true,
					"tx_enable": false,
					"rssi_offset": -202.5,
					"rssi_offset_coeff_a": 0,
					"rssi_offset_coeff_b": 0
				},{
					"rx_enable": true,
					"tx_enable": false,
					"rssi_offset": -202.5,
					"rssi_offset_coeff_a": 0,
					"rssi_offset_coeff_b": 0
				}
			],
EOF

if [ ${RADIO} -eq 0 ]
then
	cat >> ${CONFIG} << EOF
			"SX1301_conf": [
				{
					"chip_enable": true,
					"chip_center_freq": ${FREQUENCY},
					"chip_rf_chain": 0,
					"chan_LoRa_std": {
						"chan_rx_freq": ${FREQUENCY},
						"bandwidth": ${BANDWIDTH},
						"spread_factor": ${SPREADING_FACTOR}
					},
					"chan_FSK" : {
						"chan_rx_freq": ${FREQUENCY},
						"bandwidth": 15600,
						"bit_rate": 2400
					}
				},{
					"chip_enable": false
				}
			],
EOF
else
	cat >> ${CONFIG} << EOF
			"SX1301_conf": [
				{
					"chip_enable": false
				},{
					"chip_enable": true,
					"chip_center_freq": ${FREQUENCY},
					"chip_rf_chain": 1,
					"chan_LoRa_std": {
						"chan_rx_freq": ${FREQUENCY},
						"bandwidth": ${BANDWIDTH},
						"spread_factor": ${SPREADING_FACTOR}
					},
					"chan_FSK": {
						"chan_rx_freq": ${FREQUENCY},
						"bandwidth": 15600,
						"bit_rate": 2400
					}
				}
			],
EOF
fi

EUI=$(awk '{ printf "7276FF00%.8X", $1 }' /sys/fsl_otp/HW_OCOTP_GP1)

cat >> ${CONFIG} << EOF
			"FSK_sync": "C194C1",
			"loramac_public": false,
			"dsp_stat_interval": 10,
			"nb_dsp": 1,
			"aes_key": "ABCDEF0123456789ABCDEF0123456789",
			"calibration_temperature_celsius_room": 22,
			"calibration_temperature_code_ad9361": 77
		}
	],
	"gateway_conf": {
		"gateway_ID": "${EUI}",
		"log_rotate_period": 864000
	}
}
EOF

./pkt_logger -d ${DEVICE} -c ${CONFIG} &
sleep 10 && echo "**  Waiting for packets ...."

if [ ${RADIO} -eq 0 ]
then
	tail -f pktlog.csv | awk -F, '{print; print "RSSI= " $7 ", SNR= "$17}'
else
	tail -f pktlog.csv | awk -F, '{print; print "RSSI= " $9 ", SNR= "$18}'
fi
